==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'In Kästchen anzeigen',
	'affichage_documents_en_grand' => 'In groß anzeigen',
	'affichage_documents_en_liste_compacte' => 'Listenansicht',
	'aucun_audio' => 'Kein Ton',
	'aucun_document' => 'Kein Dokument',
	'aucun_file' => 'Keine Datei',
	'aucun_image' => 'Kein Bild',
	'aucun_video' => 'Keine Videos',
	'aucune_utilisation' => 'Dieses Dokument wird nicht verwendet.',
	'aucune_vignette' => 'Kein Miniaturbild',

	// B
	'bouton_ajouter_document' => 'Dokument hinzufügen',
	'bouton_ajouter_image' => 'Bild hinzufügen',
	'bouton_ajouter_image_document' => 'Bild oder Dokument hinzufügen',
	'bouton_attacher_document' => 'Anhängen',
	'bouton_copier_local' => 'Lokale Kopie anlegen',
	'bouton_download_depuis' => 'Von:',
	'bouton_download_local' => 'Mein Computer',
	'bouton_download_par_ftp' => 'FTP-Server',
	'bouton_download_par_mediatheque' => 'Mediathek',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Entfernen',
	'bouton_enlever_supprimer_document' => 'Löschen',
	'bouton_enlever_supprimer_document_confirmation' => 'Wollen sie dieses Dokument wirklich löschen?',
	'bouton_modifier_document' => 'Bearbeiten',
	'bouton_parcourir' => 'Durchsuchen...',
	'bouton_refresh_document' => 'Dokument neu laden',
	'bouton_remplacer_document' => 'Dieses Dokument ersetzen',
	'bouton_remplacer_image' => 'Dieses Bild ersetzen',
	'bouton_remplacer_image_document' => 'Durch ein Dokument oder Bild ersetzen',
	'bouton_supprimer' => 'Löschen',
	'bouton_supprimer_tous_orphelins' => 'Alle nicht verwendeten Dokumente löschen',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sind Sie sicher, dass Sie @nb@ nicht verwendete Dokumente löschen wollen?',
	'bouton_upload' => 'Hochladen',

	// D
	'des_audios' => '@nb@ Töne',
	'des_documents' => '@nb@ Dokumente',
	'des_files' => '@nb@ Dokumente',
	'des_images' => '@nb@ Bilder',
	'des_utilisations' => '@nb@ Verwendungen',
	'des_videos' => '@nb@ Videos',
	'descriptif' => 'Beschreibung',
	'details_document' => 'Details',
	'details_document_afficher_masquer' => 'Details anzeigen/verbergen.',
	'document_attache_succes' => 'Das Dokument wurde erfolgreich hinzugefügt.',
	'document_copie_locale_succes' => 'Die Datei wurde erfolgreich in auf den Server übertragen.',
	'document_installe_succes' => 'Die Datei wurde erfolgreich übertragen',
	'document_vu' => 'In den Text eingefügt.',
	'documents' => 'Mediathek',
	'documents_brises' => 'Beschädigt',
	'documents_distants' => 'Externe',
	'documents_locaux' => 'Lokale',
	'documents_non_publies' => 'Nicht veröffentlicht',
	'documents_orphelins' => 'Ungenutzt',
	'documents_publies' => 'Veröffentlicht',
	'documents_tous' => 'Alle',
	'double_clic_inserer_doc' => 'Mügen Sie mit einem Doppelklick das Kürzel in den Text ein',

	// E
	'entree_dimensions' => 'Grössenangaben:',
	'entree_titre_document' => 'Titel des Dokuments:',
	'entree_titre_image' => 'Titel des Bilds:',
	'erreur_aucun_document' => 'Dieses Dokument ist nicht in der Mediathek vorhanden.',
	'erreur_aucun_fichier' => 'Es wurde kein Dokument gefunden.',
	'erreur_autorisation' => 'Authorisierungsfehler',
	'erreur_chemin_distant' => 'Die Datei @nom@ konnte nicht über das Netz erreicht werden.',
	'erreur_chemin_ftp' => 'Die angegebene Datei wurde nicht auf dem Server gefunden.',
	'erreur_copie_fichier' => 'Die Datei @nom@ konnte nicht kopiert werden.',
	'erreur_deplacement_impossible' => 'Verschieben nicht möglich.',
	'erreur_dossier_tmp_manquant' => 'Es fehlt ein temporäres Verzeichnis zum Übertragen der Dateien',
	'erreur_ecriture_fichier' => 'Fehler beim Speichern der Datei',
	'erreur_format_fichier_image' => 'Das Format von @nom@ ist nicht als Bild geeeignet.',
	'erreur_indiquez_un_fichier' => 'Geben sie eine Datei an!',
	'erreur_insertion_document_base' => 'Das Dokument @fichier@kann nicht in der Datenbank erfasst werden.',
	'erreur_objet_absent' => 'Die empfangenen Informationen sind unvollständig.',
	'erreur_suppression_vignette' => 'Fehler beim Löschen des Thumbnails',
	'erreur_upload_type_interdit' => 'Die Übertragung von Dokumenten mit dem Namen @nom@ ist nicht erlaubt.',
	'erreur_upload_vignette' => 'Fehler beim Laden des Miniaturbilds @nom@',
	'erreurs' => '@nb@ Fehler',
	'erreurs_voir' => '@nb@ Fehler ansehen',

	// F
	'fichier_distant' => 'Externe Datei',
	'fichier_manquant' => 'Datei fehlt',
	'fichier_modifie' => 'Die Datei wurde geändert. Klicken sie hier zum Speichern.',
	'format_date_incorrect' => 'Datum oder Uhrzeit sind falsch.',

	// I
	'icone_creer_document' => 'Dokument hinzufügen',
	'id' => 'ID',
	'image_tourner_180' => 'Um 180° drehen',
	'image_tourner_droite' => 'Um 90° nach rechts drehen',
	'image_tourner_gauche' => 'Um 90° nach links drehen',
	'info_alt' => 'Beschreibung des Inhalts des Bildes, wenn es nicht sichtbar ist, zusätzlich zum Titel.',
	'info_dimensions_image' => 'Größe',
	'info_doc_max_poids' => 'Die Dokumente dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Dokument nicht verfügbar',
	'info_documents' => 'Dokumente',
	'info_duree' => 'Dauer',
	'info_gauche_numero_document' => 'DOKUMENT NUMMER',
	'info_hauteur' => 'Höhe',
	'info_heure' => 'Stunde',
	'info_illustrations' => 'Illustrationen',
	'info_image_max_poids' => 'Die Bilder dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_image_max_taille' => 'Die Bilder dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_image_min_taille' => 'Bilder müssen mindestens @mini@ haben (diese Datei hat @actual@).',
	'info_inclusion_directe' => 'Direkte Einbindung:',
	'info_inclusion_vignette' => 'Einbindung des Icons:',
	'info_installer_tous_documents' => 'Alle Dokumente installieren',
	'info_largeur' => 'Breite',
	'info_logo_max_taille' => 'Die Logogrösse darf nicht @maxi@ überschreiten (aktuelle Dateigrösse @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Dokument bearbeiten',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Dokument im Internet verlinken:',
	'info_resolution_image' => 'Auflösung',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Ohne Icon',
	'info_statut_document' => 'Dieses Dokument ist:',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Von Ihrem Computer hochladen:',
	'info_utilisation' => 'Verwendunge(en)',
	'infos' => 'Technische Informationen',
	'inserer_raccourci' => 'Kürzel in den Text einfügen',
	'item_autoriser_selectionner_date_en_ligne' => 'Festlegen eines Datums für jedes Dokument gestatten',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Das Datum der Dokumente entspricht dem Zeitpunkt des Uploads.',

	// L
	'label_activer_document_objets' => 'Hochladen von Dokumenten erlauben für:',
	'label_alt' => 'Textalternative (alt)',
	'label_apercu' => 'Vorschau',
	'label_caracteristiques' => 'Eigenschaften',
	'label_credits' => 'Beteiligte',
	'label_fichier' => 'Datei',
	'label_fichier_vignette' => 'Miniaturbild',
	'label_paginer_par' => 'Seitenweise sortieren nach:',
	'label_parents' => 'Dieses Dokument gehört zu',
	'label_refdoc_joindre' => 'Dokument Nummer',
	'label_titre_mimetype' => 'Dateityp',
	'lien_tout_desordonner' => 'Sortierung zurücksetzen',
	'lien_tout_desordonner_verif' => 'Die Sortierung für diese Liste von Dokumenten wird zurückgesetzt. Sind Sie sicher?',
	'lien_tout_enlever' => 'Alle entfernen',
	'lien_tout_enlever_verif' => 'Möchten sie alle Dokumente entfernen ?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Töne',
	'media_file' => 'Andere',
	'media_image' => 'Bilder',
	'media_video' => 'Videos',
	'miniature_automatique_active' => 'SPIP wird automatisch eine Verkleinerung des Bildes herstellen',

	// N
	'nb_documents_attache_succes' => '@nb@ Dokumente wurden hinzugefügt',
	'nb_documents_installe_succes' => '@nb@ Dateien wurden erfolgreich übertragen.',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumente',
	'ordonner_ce_document' => 'Dieses Dokument einordnen',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Höhe',
	'par_id' => 'ID',
	'par_largeur' => 'Breite',
	'par_taille' => 'Größe',
	'par_titre' => 'Titel',

	// T
	'texte_documents_joints' => 'Sie können die Zuordnung von Dokumenten (Office-Dokumente, Bilder, Multimedia-Dateien, etc.) zu Artikeln und/oder Rubriken erlauben. Diese Dokumente können anschliessend innerhalb von Artikeln verlinkt oder separat angezeigt werden.',
	'texte_documents_joints_2' => 'Diese Einstellung verhindert weder das Einfügen von Bildern noch von Dokumenten in den Text von Artikeln.',
	'titre_documents_joints' => 'Dokumente',
	'titre_page_documents_edit' => 'Dokument bearbeiten: @titre@',
	'tous_les_medias' => 'Alle Medien',
	'tout_dossier_upload' => 'Das ganze Verzeichnis @upload@',
	'tout_voir' => 'Alle anzeigen',

	// U
	'un_audio' => '1 Tondokument',
	'un_document' => '1 Dokument',
	'un_file' => '1 Dokument',
	'un_image' => '1 Bild',
	'un_video' => '1 Video',
	'une_utilisation' => '1 Verwendung',
	'upload_fichier_zip' => 'ZIP-Datei',
	'upload_fichier_zip_texte' => 'Sie möchsten eine ZIP-Datei installieren.',
	'upload_fichier_zip_texte2' => 'SPIP kann:',
	'upload_info_mode_document' => 'Im Portfolio ablegen',
	'upload_info_mode_image' => 'Aus dem Portfolio entfernen',
	'upload_limit' => 'Datei zu gross zum Hochladen. Maximale <i>upload</i>-Grösse: @max@.',
	'upload_zip_conserver' => 'Archiv nach Entpacken beibehalten',
	'upload_zip_decompacter' => 'Das ZIP-Archiv auspacken. Diese Dateien werden dann auf dem Server installiert:',
	'upload_zip_mode_document' => 'Alle Bilder im Portfolio ablegen',
	'upload_zip_telquel' => 'Das ZIP-Archiv als eine Archivdatei installieren.',
	'upload_zip_titrer' => 'Dateinamen als Titel verwenden',

	// V
	'verifier_documents_brises' => 'Fehlende Dateien prüfen',
	'verifier_documents_inutilises' => 'Links der Dokumente prüfen',
	'vignette_supprimee' => 'Das MIniaturbild wurde gelöscht.'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'In Kästchen anzeigen',
	'affichage_documents_en_grand' => 'In groß anzeigen',
	'affichage_documents_en_liste_compacte' => 'Listenansicht',
	'aucun_audio' => 'Kein Ton',
	'aucun_document' => 'Kein Dokument',
	'aucun_file' => 'Keine Datei',
	'aucun_image' => 'Kein Bild',
	'aucun_video' => 'Keine Videos',
	'aucune_utilisation' => 'Dieses Dokument wird nicht verwendet.',
	'aucune_vignette' => 'Kein Miniaturbild',

	// B
	'bouton_ajouter_document' => 'Dokument hinzufügen',
	'bouton_ajouter_image' => 'Bild hinzufügen',
	'bouton_ajouter_image_document' => 'Bild oder Dokument hinzufügen',
	'bouton_attacher_document' => 'Anhängen',
	'bouton_copier_local' => 'Lokale Kopie anlegen',
	'bouton_download_depuis' => 'Von:',
	'bouton_download_local' => 'Mein Computer',
	'bouton_download_par_ftp' => 'FTP-Server',
	'bouton_download_par_mediatheque' => 'Mediathek',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Entfernen',
	'bouton_enlever_supprimer_document' => 'Löschen',
	'bouton_enlever_supprimer_document_confirmation' => 'Wollen sie dieses Dokument wirklich löschen?',
	'bouton_modifier_document' => 'Bearbeiten',
	'bouton_parcourir' => 'Durchsuchen...',
	'bouton_refresh_document' => 'Dokument neu laden',
	'bouton_remplacer_document' => 'Dieses Dokument ersetzen',
	'bouton_remplacer_image' => 'Dieses Bild ersetzen',
	'bouton_remplacer_image_document' => 'Durch ein Dokument oder Bild ersetzen',
	'bouton_supprimer' => 'Löschen',
	'bouton_supprimer_tous_orphelins' => 'Alle nicht verwendeten Dokumente löschen',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sind Sie sicher, dass Sie @nb@ nicht verwendete Dokumente löschen wollen?',
	'bouton_upload' => 'Hochladen',

	// D
	'des_audios' => '@nb@ Töne',
	'des_documents' => '@nb@ Dokumente',
	'des_files' => '@nb@ Dokumente',
	'des_images' => '@nb@ Bilder',
	'des_utilisations' => '@nb@ Verwendungen',
	'des_videos' => '@nb@ Videos',
	'descriptif' => 'Beschreibung',
	'details_document' => 'Details',
	'details_document_afficher_masquer' => 'Details anzeigen/verbergen.',
	'document_attache_succes' => 'Das Dokument wurde erfolgreich hinzugefügt.',
	'document_copie_locale_succes' => 'Die Datei wurde erfolgreich in auf den Server übertragen.',
	'document_installe_succes' => 'Die Datei wurde erfolgreich übertragen',
	'document_vu' => 'In den Text eingefügt.',
	'documents' => 'Mediathek',
	'documents_brises' => 'Beschädigt',
	'documents_distants' => 'Externe',
	'documents_locaux' => 'Lokale',
	'documents_non_publies' => 'Nicht veröffentlicht',
	'documents_orphelins' => 'Ungenutzt',
	'documents_publies' => 'Veröffentlicht',
	'documents_tous' => 'Alle',
	'double_clic_inserer_doc' => 'Mügen Sie mit einem Doppelklick das Kürzel in den Text ein',

	// E
	'entree_dimensions' => 'Grössenangaben:',
	'entree_titre_document' => 'Titel des Dokuments:',
	'entree_titre_image' => 'Titel des Bilds:',
	'erreur_aucun_document' => 'Dieses Dokument ist nicht in der Mediathek vorhanden.',
	'erreur_aucun_fichier' => 'Es wurde kein Dokument gefunden.',
	'erreur_autorisation' => 'Authorisierungsfehler',
	'erreur_chemin_distant' => 'Die Datei @nom@ konnte nicht über das Netz erreicht werden.',
	'erreur_chemin_ftp' => 'Die angegebene Datei wurde nicht auf dem Server gefunden.',
	'erreur_copie_fichier' => 'Die Datei @nom@ konnte nicht kopiert werden.',
	'erreur_deplacement_impossible' => 'Verschieben nicht möglich.',
	'erreur_dossier_tmp_manquant' => 'Es fehlt ein temporäres Verzeichnis zum Übertragen der Dateien',
	'erreur_ecriture_fichier' => 'Fehler beim Speichern der Datei',
	'erreur_format_fichier_image' => 'Das Format von @nom@ ist nicht als Bild geeeignet.',
	'erreur_indiquez_un_fichier' => 'Geben sie eine Datei an!',
	'erreur_insertion_document_base' => 'Das Dokument @fichier@kann nicht in der Datenbank erfasst werden.',
	'erreur_objet_absent' => 'Die empfangenen Informationen sind unvollständig.',
	'erreur_suppression_vignette' => 'Fehler beim Löschen des Thumbnails',
	'erreur_upload_type_interdit' => 'Die Übertragung von Dokumenten mit dem Namen @nom@ ist nicht erlaubt.',
	'erreur_upload_vignette' => 'Fehler beim Laden des Miniaturbilds @nom@',
	'erreurs' => '@nb@ Fehler',
	'erreurs_voir' => '@nb@ Fehler ansehen',

	// F
	'fichier_distant' => 'Externe Datei',
	'fichier_manquant' => 'Datei fehlt',
	'fichier_modifie' => 'Die Datei wurde geändert. Klicken sie hier zum Speichern.',
	'format_date_incorrect' => 'Datum oder Uhrzeit sind falsch.',

	// I
	'icone_creer_document' => 'Dokument hinzufügen',
	'id' => 'ID',
	'image_tourner_180' => 'Um 180° drehen',
	'image_tourner_droite' => 'Um 90° nach rechts drehen',
	'image_tourner_gauche' => 'Um 90° nach links drehen',
	'info_alt' => 'Beschreibung des Inhalts des Bildes, wenn es nicht sichtbar ist, zusätzlich zum Titel.',
	'info_dimensions_image' => 'Größe',
	'info_doc_max_poids' => 'Die Dokumente dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Dokument nicht verfügbar',
	'info_documents' => 'Dokumente',
	'info_duree' => 'Dauer',
	'info_gauche_numero_document' => 'DOKUMENT NUMMER',
	'info_hauteur' => 'Höhe',
	'info_heure' => 'Stunde',
	'info_illustrations' => 'Illustrationen',
	'info_image_max_poids' => 'Die Bilder dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_image_max_taille' => 'Die Bilder dürfen höchstens @maxi@ groß sein (diese Datei hat @actuel@).',
	'info_image_min_taille' => 'Bilder müssen mindestens @mini@ haben (diese Datei hat @actual@).',
	'info_inclusion_directe' => 'Direkte Einbindung:',
	'info_inclusion_vignette' => 'Einbindung des Icons:',
	'info_installer_tous_documents' => 'Alle Dokumente installieren',
	'info_largeur' => 'Breite',
	'info_logo_max_taille' => 'Die Logogrösse darf nicht @maxi@ überschreiten (aktuelle Dateigrösse @actuel@).',
	'info_mode' => 'Modus',
	'info_modifier_document' => 'Dokument bearbeiten',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Dokument im Internet verlinken:',
	'info_resolution_image' => 'Auflösung',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Ohne Icon',
	'info_statut_document' => 'Dieses Dokument ist:',
	'info_taille' => 'Gewicht',
	'info_telecharger' => 'Von Ihrem Computer hochladen:',
	'info_utilisation' => 'Verwendunge(en)',
	'infos' => 'Technische Informationen',
	'inserer_raccourci' => 'Kürzel in den Text einfügen',
	'item_autoriser_selectionner_date_en_ligne' => 'Festlegen eines Datums für jedes Dokument gestatten',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Das Datum der Dokumente entspricht dem Zeitpunkt des Uploads.',

	// L
	'label_activer_document_objets' => 'Hochladen von Dokumenten erlauben für:',
	'label_alt' => 'Textalternative (alt)',
	'label_apercu' => 'Vorschau',
	'label_caracteristiques' => 'Eigenschaften',
	'label_credits' => 'Beteiligte',
	'label_fichier' => 'Datei',
	'label_fichier_vignette' => 'Miniaturbild',
	'label_paginer_par' => 'Seitenweise sortieren nach:',
	'label_parents' => 'Dieses Dokument gehört zu',
	'label_refdoc_joindre' => 'Dokument Nummer',
	'label_titre_mimetype' => 'Dateityp',
	'lien_tout_desordonner' => 'Sortierung zurücksetzen',
	'lien_tout_desordonner_verif' => 'Die Sortierung für diese Liste von Dokumenten wird zurückgesetzt. Sind Sie sicher?',
	'lien_tout_enlever' => 'Alle entfernen',
	'lien_tout_enlever_verif' => 'Möchten sie alle Dokumente entfernen ?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Töne',
	'media_file' => 'Andere',
	'media_image' => 'Bilder',
	'media_video' => 'Videos',
	'miniature_automatique_active' => 'SPIP wird automatisch eine Verkleinerung des Bildes herstellen',

	// N
	'nb_documents_attache_succes' => '@nb@ Dokumente wurden hinzugefügt',
	'nb_documents_installe_succes' => '@nb@ Dateien wurden erfolgreich übertragen.',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumente',
	'ordonner_ce_document' => 'Dieses Dokument einordnen',

	// P
	'par_date' => 'Datum',
	'par_hauteur' => 'Höhe',
	'par_id' => 'ID',
	'par_largeur' => 'Breite',
	'par_taille' => 'Größe',
	'par_titre' => 'Titel',

	// T
	'texte_documents_joints' => 'Sie können die Zuordnung von Dokumenten (Office-Dokumente, Bilder, Multimedia-Dateien, etc.) zu Artikeln und/oder Rubriken erlauben. Diese Dokumente können anschliessend innerhalb von Artikeln verlinkt oder separat angezeigt werden.',
	'texte_documents_joints_2' => 'Diese Einstellung verhindert weder das Einfügen von Bildern noch von Dokumenten in den Text von Artikeln.',
	'titre_documents_joints' => 'Dokumente',
	'titre_page_documents_edit' => 'Dokument bearbeiten: @titre@',
	'tous_les_medias' => 'Alle Medien',
	'tout_dossier_upload' => 'Das ganze Verzeichnis @upload@',
	'tout_voir' => 'Alle anzeigen',

	// U
	'un_audio' => '1 Tondokument',
	'un_document' => '1 Dokument',
	'un_file' => '1 Dokument',
	'un_image' => '1 Bild',
	'un_video' => '1 Video',
	'une_utilisation' => '1 Verwendung',
	'upload_fichier_zip' => 'ZIP-Datei',
	'upload_fichier_zip_texte' => 'Sie möchsten eine ZIP-Datei installieren.',
	'upload_fichier_zip_texte2' => 'SPIP kann:',
	'upload_info_mode_document' => 'Im Portfolio ablegen',
	'upload_info_mode_image' => 'Aus dem Portfolio entfernen',
	'upload_limit' => 'Datei zu gross zum Hochladen. Maximale <i>upload</i>-Grösse: @max@.',
	'upload_zip_conserver' => 'Archiv nach Entpacken beibehalten',
	'upload_zip_decompacter' => 'Das ZIP-Archiv auspacken. Diese Dateien werden dann auf dem Server installiert:',
	'upload_zip_mode_document' => 'Alle Bilder im Portfolio ablegen',
	'upload_zip_telquel' => 'Das ZIP-Archiv als eine Archivdatei installieren.',
	'upload_zip_titrer' => 'Dateinamen als Titel verwenden',

	// V
	'verifier_documents_brises' => 'Fehlende Dateien prüfen',
	'verifier_documents_inutilises' => 'Links der Dokumente prüfen',
	'vignette_supprimee' => 'Das Miniaturbild wurde gelöscht.'
);
